function alq=calcalNinf(ga,x,y,dx,dy)
%
%   
% S. Ulbrich, June 2002
%
% This code comes with no guarantee or warranty of any kind.
%
%  function alq=calcalNinf(ga,x,y,dx,dy)
%
%  computes the maximal 0<=alq<=1 such that
%  (x(al),y(al)) in N-inf(ga) for all 0<=al<=alq,
%
%  i.e.,   (X+al*dX) (y+al*dy)>=ga*(x+al*dx)'*(y+al*dy)/n
%
%  This gives n polynomials of second order for al and we
%  determine the smallest positiv root of them
%

n=size(x,1);
% determine maximal 0<=al<=1 with (x+al*dx)>=0, (y+al*dy)>=0
msk=(dx<0);
alx1=1;
if any(msk)
 alx1=min(-x(msk)./dx(msk));
end
aly1=1;
msk=(dy<0);
if any(msk)
 aly1=min(-y(msk)./dy(msk));
end
al=min([1,alx1,aly1]);
% compute the coefficients of the n quadratic polynomials
b=y.*dx+x.*dy-ga*(y'*dx+x'*dy)/n;
a=dx.*dy-ga*(dx'*dy)/n;
c=x.*y-ga*(x'*y)/n;
al1=al*ones(n,1);
%
% Consider the possible cases to determine the smallest positiv root
% case ai=0, bi<0; then ci>0
msk1=(abs(a)<=1e-20);
msk2=msk1&(b<0);
if any(msk2)
 al1(msk2)=-c(msk2)./b(msk2);
end
% case ai>0, bi<0; then ci>0
msk1=(a>1e-20)&(b<0);
if any(msk1)
 al1(msk1)=(-2*c(msk1))./(b(msk1)-sqrt(b(msk1).^2-4*a(msk1).*c(msk1)));
end
% case ai<0, bi<0; then ci>0
msk1=(a<-1e-20)&(b<0);
if any(msk1)
 al1(msk1)=(-2*c(msk1))./(b(msk1)-sqrt(b(msk1).^2-4*a(msk1).*c(msk1)));
end
% case ai<0, bi>=0
msk1=(a<-1e-20)&(b>=0);
if any(msk1)
 al1(msk1)=(-b(msk1)-sqrt(b(msk1).^2-4*a(msk1).*c(msk1)))./(2*a(msk1));
end
alq=min([al;al1]);
